aboutsummaryrefslogtreecommitdiff
path: root/src/profiling/PeriodicCounterCapture.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/profiling/PeriodicCounterCapture.cpp')
-rw-r--r--src/profiling/PeriodicCounterCapture.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/profiling/PeriodicCounterCapture.cpp b/src/profiling/PeriodicCounterCapture.cpp
index d914e85cfb..11ad6511fe 100644
--- a/src/profiling/PeriodicCounterCapture.cpp
+++ b/src/profiling/PeriodicCounterCapture.cpp
@@ -9,10 +9,10 @@
#include <iostream>
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
void PeriodicCounterCapture::Start()
@@ -105,7 +105,7 @@ void PeriodicCounterCapture::Capture(IReadCounterValues& readCounterValues)
{
counterValue = readCounterValues.GetDeltaCounterValue(requestedId);
}
- catch (const Exception& e)
+ catch (const armnn::Exception& e)
{
// Report the error and continue
ARMNN_LOG(warning) << "An error has occurred when getting a counter value: "
@@ -134,6 +134,6 @@ void PeriodicCounterCapture::Capture(IReadCounterValues& readCounterValues)
while (m_KeepRunning.load());
}
-} // namespace profiling
+} // namespace pipe
-} // namespace armnn \ No newline at end of file
+} // namespace arm \ No newline at end of file